main.view-root[data-v-0314b491]{min-height:100vh;align-items:center;justify-content:center;padding:2rem 1rem}.reset-container[data-v-0314b491]{max-width:520px;margin:0 auto;width:100%;display:flex;flex-direction:column;gap:1.75rem}.section-body[data-v-0314b491]{gap:1.25rem}.name-edit span[data-v-0314b491]{color:var(--color-text-muted);font-size:.9rem}
